&lt;template&gt;
  &lt;div class="comments-container max-w-4xl mx-auto p-4"&gt;
    &lt;!-- 用户认证部分 --&gt;
    &lt;div v-if="!user" class="mb-8 bg-white rounded-lg shadow p-6"&gt;
      &lt;div class="flex justify-between items-center mb-6"&gt;
        &lt;h3 class="text-xl font-semibold text-gray-800"&gt;加入讨论&lt;/h3&gt;
        &lt;div class="space-x-4"&gt;
          &lt;button @click="showLoginForm = true; showRegisterForm = false" 
                  class="px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600 transition"&gt;
            登录
          &lt;/button&gt;
          &lt;button @click="showRegisterForm = true; showLoginForm = false"
                  class="px-4 py-2 bg-green-500 text-white rounded hover:bg-green-600 transition"&gt;
            注册
          &lt;/button&gt;
        &lt;/div&gt;
      &lt;/div&gt;

      &lt;!-- 登录表单 --&gt;
      &lt;div v-if="showLoginForm" class="bg-gray-50 rounded-lg p-6"&gt;
        &lt;h4 class="text-lg font-medium text-gray-700 mb-4"&gt;登录&lt;/h4&gt;
        &lt;form @submit.prevent="login" class="space-y-4"&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;用户名&lt;/label&gt;
            &lt;input v-model="loginForm.username" type="text" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;密码&lt;/label&gt;
            &lt;input v-model="loginForm.password" type="password" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;button type="submit" 
                  class="w-full px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600 transition"&gt;
            登录
          &lt;/button&gt;
        &lt;/form&gt;
      &lt;/div&gt;

      &lt;!-- 注册表单 --&gt;
      &lt;div v-if="showRegisterForm" class="bg-gray-50 rounded-lg p-6"&gt;
        &lt;h4 class="text-lg font-medium text-gray-700 mb-4"&gt;注册新账号&lt;/h4&gt;
        &lt;form @submit.prevent="register" class="space-y-4"&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;用户名&lt;/label&gt;
            &lt;input v-model="registerForm.username" type="text" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;邮箱&lt;/label&gt;
            &lt;input v-model="registerForm.email" type="email" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;密码&lt;/label&gt;
            &lt;input v-model="registerForm.password" type="password" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;div&gt;
            &lt;label class="block text-sm font-medium text-gray-700"&gt;确认密码&lt;/label&gt;
            &lt;input v-model="registerForm.confirmPassword" type="password" required
                   class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"&gt;
          &lt;/div&gt;
          &lt;button type="submit" 
                  class="w-full px-4 py-2 bg-green-500 text-white rounded hover:bg-green-600 transition"&gt;
            注册
          &lt;/button&gt;
        &lt;/form&gt;
      &lt;/div&gt;
    &lt;/div&gt;

    &lt;!-- 已登录用户信息 --&gt;
    &lt;div v-else class="mb-8 bg-white rounded-lg shadow p-6"&gt;
      &lt;div class="flex justify-between items-center"&gt;
        &lt;div class="flex items-center space-x-4"&gt;
          &lt;img :src="user.avatar || '/images/default-avatar.png'" 
               :alt="user.username"
               class="w-10 h-10 rounded-full"&gt;
          &lt;div&gt;
            &lt;h3 class="font-medium text-gray-800"&gt;{{ user.username }}&lt;/h3&gt;
            &lt;p class="text-sm text-gray-500"&gt;{{ user.email }}&lt;/p&gt;
          &lt;/div&gt;
        &lt;/div&gt;
        &lt;button @click="logout" 
                class="px-4 py-2 bg-gray-200 text-gray-700 rounded hover:bg-gray-300 transition"&gt;
          退出登录
        &lt;/button&gt;
      &lt;/div&gt;
    &lt;/div&gt;

    &lt;!-- 评论列表 --&gt;
    &lt;div class="space-y-6"&gt;
      &lt;!-- 评论输入框 --&gt;
      &lt;div v-if="user" class="bg-white rounded-lg shadow p-6"&gt;
        &lt;h3 class="text-lg font-medium text-gray-800 mb-4"&gt;发表评论&lt;/h3&gt;
        &lt;form @submit.prevent="submitComment" class="space-y-4"&gt;
          &lt;textarea v-model="newComment" 
                    placeholder="写下你的想法..."
                    rows="4"
                    class="w-full p-3 border border-gray-300 rounded-md focus:ring-blue-500 focus:border-blue-500"&gt;&lt;/textarea&gt;
          &lt;div class="flex justify-end"&gt;
            &lt;button type="submit" 
                    class="px-6 py-2 bg-blue-500 text-white rounded hover:bg-blue-600 transition"&gt;
              发表评论
            &lt;/button&gt;
          &lt;/div&gt;
        &lt;/form&gt;
      &lt;/div&gt;

      &lt;!-- 评论展示 --&gt;
      &lt;div v-if="comments.length &gt; 0" class="space-y-4"&gt;
        &lt;comment-item
          v-for="comment in comments"
          :key="comment.id"
          :comment="comment"
          :current-user="user"
          @reply="handleReply"
          @edit="handleEdit"
          @delete="handleDelete"
          @like="handleLike"
        /&gt;
      &lt;/div&gt;
      &lt;div v-else class="text-center py-8 text-gray-500"&gt;
        暂无评论，来说两句吧~
      &lt;/div&gt;
    &lt;/div&gt;
  &lt;/div&gt;
&lt;/template&gt;

&lt;script&gt;
export default {
  name: 'CommentSystem',
  props: {
    postPath: {
      type: String,
      required: true
    }
  },
  data() {
    return {
      comments: [],
      newComment: '',
      user: null,
      showLoginForm: false,
      showRegisterForm: false,
      loginForm: {
        username: '',
        password: ''
      },
      registerForm: {
        username: '',
        email: '',
        password: '',
        confirmPassword: ''
      },
      error: null,
      loading: false
    }
  },
  methods: {
    async fetchComments() {
      try {
        this.loading = true;
        const response = await axios.get(`/api/comments?postPath=${this.postPath}`);
        this.comments = response.data;
      } catch (error) {
        this.error = '获取评论失败';
        console.error('Error fetching comments:', error);
      } finally {
        this.loading = false;
      }
    },
    async submitComment() {
      if (!this.newComment.trim()) return;
      
      try {
        const response = await axios.post('/api/comments', {
          postPath: this.postPath,
          content: this.newComment
        });
        this.comments.push(response.data);
        this.newComment = '';
      } catch (error) {
        this.error = '提交评论失败';
        console.error('Error submitting comment:', error);
      }
    },
    async login() {
      try {
        const response = await axios.post('/api/auth/login', this.loginForm);
        localStorage.setItem('token', response.data.token);
        this.user = response.data.user;
        this.showLoginForm = false;
        this.loginForm = { username: '', password: '' };
      } catch (error) {
        this.error = '登录失败';
        console.error('Error logging in:', error);
      }
    },
    async register() {
      if (this.registerForm.password !== this.registerForm.confirmPassword) {
        this.error = '两次输入的密码不一致';
        return;
      }

      try {
        const response = await axios.post('/api/auth/register', {
          username: this.registerForm.username,
          email: this.registerForm.email,
          password: this.registerForm.password
        });
        localStorage.setItem('token', response.data.token);
        this.user = response.data.user;
        this.showRegisterForm = false;
        this.registerForm = { username: '', email: '', password: '', confirmPassword: '' };
      } catch (error) {
        this.error = '注册失败';
        console.error('Error registering:', error);
      }
    },
    logout() {
      localStorage.removeItem('token');
      this.user = null;
    },
    checkAuth() {
      const token = localStorage.getItem('token');
      if (token) {
        axios.get('/api/auth/user')
          .then(response => {
            this.user = response.data;
          })
          .catch(() => {
            localStorage.removeItem('token');
            this.user = null;
          });
      }
    }
  },
  mounted() {
    this.checkAuth();
    this.fetchComments();
  }
};
&lt;/script&gt;
